pub struct EigenConfig {
pub disperser_rpc: String,
pub eth_rpc_url: SecretUrl,
pub settlement_layer_confirmation_depth: u32,
pub eigenda_svc_manager_address: H160,
pub wait_for_finalization: bool,
pub authenticated: bool,
pub srs_points_source: SrsPointsSource,
pub custom_quorum_numbers: Vec<u8>,
}Expand description
Configuration for the EigenDA remote disperser client.
Fields
disperser_rpc: StringURL of the Disperser RPC server
eth_rpc_url: SecretUrlURL of the Ethereum RPC server
settlement_layer_confirmation_depth: u32Block height needed to reach in order to consider the blob finalized a value less or equal to 0 means that the disperser will not wait for finalization
eigenda_svc_manager_address: H160Address of the service manager contract
wait_for_finalization: boolWait for the blob to be finalized before returning the response
authenticated: boolAuthenticated dispersal
srs_points_source: SrsPointsSourcePoints source
custom_quorum_numbers: Vec<u8>Custom quorum numbers
Implementations
Sourceimpl EigenConfig
impl EigenConfig
Sourcepub fn new(
disperser_rpc: String,
eth_rpc_url: SecretUrl,
settlement_layer_confirmation_depth: u32,
eigenda_svc_manager_address: H160,
wait_for_finalization: bool,
authenticated: bool,
srs_points_source: SrsPointsSource,
custom_quorum_numbers: Vec<u8>,
) -> Result<Self, ConfigError>
pub fn new( disperser_rpc: String, eth_rpc_url: SecretUrl, settlement_layer_confirmation_depth: u32, eigenda_svc_manager_address: H160, wait_for_finalization: bool, authenticated: bool, srs_points_source: SrsPointsSource, custom_quorum_numbers: Vec<u8>, ) -> Result<Self, ConfigError>
Create a new EigenConfig